﻿#include <stdio.h>
#include <string.h>
#include <vector>
#include "example.h"
#include "htra_api.h"
using namespace std;

#define IS_USB 1 //默认使用的是USB型设备，若使用的是网口型设备则将IS_USB定义为0。

int SWP_GetSpectrum_TraceAlign()
{
	int Status = 0;      //函数的返回。
	void* Device = NULL; //当前设备的内存地址。
	int DevNum = 0;      //指定设备号。

	BootProfile_TypeDef BootProfile; //启动配置结构体，包括物理接口、供电方式等。
	BootInfo_TypeDef BootInfo;       //启动信息结构体，包括设备信息、USB速率等。

	BootProfile.DevicePowerSupply = USBPortAndPowerPort; //使用USB数据端口及独立电源端口双供电。

#if IS_USB==1
	//配置USB接口。
	BootProfile.PhysicalInterface = USB;
#else 
	//配置ETH接口。
	BootProfile.PhysicalInterface = ETH;
	BootProfile.ETH_IPVersion = IPv4;
	BootProfile.ETH_RemotePort = 5000;
	BootProfile.ETH_ReadTimeOut = 5000;
	BootProfile.ETH_IPAddress[0] = 192;
	BootProfile.ETH_IPAddress[1] = 168;
	BootProfile.ETH_IPAddress[2] = 1;
	BootProfile.ETH_IPAddress[3] = 100;
#endif

	Status = Device_Open(&Device, DevNum, &BootProfile, &BootInfo);              //打开设备。

	Device_Open_ErrorHandling(Status, &Device, DevNum, &BootProfile, &BootInfo); //当Status不为0时，根据Status的返回值进行相对应的错误处理。

	SWP_Profile_TypeDef SWP_ProfileIn;  //SWP输入配置，包括起始频率、终止频率、RBW、参考电平等。
	SWP_Profile_TypeDef SWP_ProfileOut; //SWP输出配置。
	SWP_TraceInfo_TypeDef TraceInfo;    //当前配置下的迹线信息，包括迹线点数、跳频点数等。

	SWP_ProfileDeInit(&Device, &SWP_ProfileIn); //初始化SWP模式的相关参数。

	SWP_ProfileIn.StartFreq_Hz = 9e3;        //配置起始频率。
	SWP_ProfileIn.StopFreq_Hz = 6.35e9;      //配置终止频率。
	SWP_ProfileIn.RBW_Hz = 300e3;            //配置RBW。
	SWP_ProfileIn.TraceAlign = AlignToStart; //迹线对其方式为对其至起始频率,若需对其中心频率请将此参数设置为AlignToCenter

	Status = SWP_Configuration(&Device, &SWP_ProfileIn, &SWP_ProfileOut, &TraceInfo);                                               //通过调用此函数下发SWP模式的相关配置。

	SWP_Configuration_ErrorHandling(Status, &Device, DevNum, &BootProfile, &BootInfo, &SWP_ProfileIn, &SWP_ProfileOut, &TraceInfo); //当Status不为0时，根据Status的返回值进行相对应的错误处理。

	//当调用SWP_GetPartialSweep()按帧获取频谱数据时，对齐起始频率/中心频率相较于自然对齐会有补0的情况，不可直接使用TraceInfo.FullsweepTracePoints为数组开空间。
	//调用SWP_GetFullSweep()获取数据时可直接使用TraceInfo.FullsweepTracePoints为数组开空间。
	vector<double> Frequency(TraceInfo.PartialsweepTracePoints * TraceInfo.TotalHops);    //创建频率数组。
	vector<float> PowerSpec_dBm(TraceInfo.PartialsweepTracePoints * TraceInfo.TotalHops); //创建功率数组。

	//存储截去补零后的频谱和幅度数据。
	vector<double> Frequency_c(TraceInfo.FullsweepTracePoints);    //创建频率数组。
	vector<float> PowerSpec_dBm_c(TraceInfo.FullsweepTracePoints); //创建频率数组。
	int HopIndex = 0;                                              //当前跳频点索引。
	int FrameIndex = 0;                                            //当前帧索引。
	MeasAuxInfo_TypeDef MeasAuxInfo;                               //测量数据的辅助信息，包括：功率最大值索引、功率最大值、设备温度、经纬度、绝对时间戳等。

	//循环获取数据。
	while (1)
	{
		for (int i = 0; i < TraceInfo.TotalHops; i++) //TraceInfo.TotalHops代表当前配置下的帧数，因此循环TraceInfo.TotalHops次调用SWP_GetPartialSweep即可得到完整迹线。
		{
			Status = SWP_GetPartialSweep(&Device, Frequency.data() + i * TraceInfo.PartialsweepTracePoints, PowerSpec_dBm.data() + i * TraceInfo.PartialsweepTracePoints, &HopIndex, &FrameIndex, &MeasAuxInfo); //获取频谱数据。

			if (Status == APIRETVAL_NoError)
			{
				// UserCode here
				/*

				例如：显示频谱 或 对频谱做其他处理等

				*/
			}

			else //当Status不为0时，根据Status的返回值进行相对应的错误处理。
			{
				SWP_ErrorHandlingExceptOpenAndConfiguration(Status, &Device, DevNum, &BootProfile, &BootInfo, &SWP_ProfileIn, &SWP_ProfileOut, &TraceInfo);
			}

		}

		memcpy(Frequency_c.data(), Frequency.data(), sizeof(double)* TraceInfo.FullsweepTracePoints);         //存储截去补零后的频率数据。
		memcpy(PowerSpec_dBm_c.data(), PowerSpec_dBm.data(), sizeof(float) * TraceInfo.FullsweepTracePoints); //存储截去补零后的功率数据。
	}

	Device_Close(&Device); //关闭设备。

	return 0;
}